@@ -19,7 +19,7 @@ use Farly::Transport::PortLT;
 use Farly::Transport::PortRange;
 use Farly::Transport::Protocol;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 our ($volume,$dir,$file) = File::Spec->splitpath( $INC{'Farly.pm'} );
 Log::Log4perl::init( $volume.$dir.'Farly/Log/Farly.conf');
@@ -130,6 +130,18 @@ Returns Object::KVC::List<Object::KVC::Hash> firewall device model.
 Valid firewall types:
  ASA  - Cisco ASA firewall
 
+=AUTHOR
+
+Trystan Johnson
+
+=CONTRIBUTORS
+
+=over
+
+=item *  Lukas Thiemeier <lukast@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENCE
 
 Farly
@@ -146,4 +158,4 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
\ No newline at end of file
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
